diff --git a/dashboard/login.html b/dashboard/oidc_login.html
similarity index 100%
rename from dashboard/login.html
rename to dashboard/oidc_login.html
diff --git a/dashboard/src/views/LoginView.vue b/dashboard/src/views/LoginView.vue
index ede45c742..9e581daf5 100644
--- a/dashboard/src/views/LoginView.vue
+++ b/dashboard/src/views/LoginView.vue
@@ -15,7 +15,7 @@ const password = ref('');
const totpToken = ref('');
const totpTokenRequired = ref(false);
-// coming from login.html template
+// coming from oidc_login.html template
const name = window.cloudron.name;
const note = window.cloudron.note;
const iconUrl = window.cloudron.iconUrl;
diff --git a/dashboard/vite.config.mjs b/dashboard/vite.config.mjs
index b55b2a235..9c6cc7961 100644
--- a/dashboard/vite.config.mjs
+++ b/dashboard/vite.config.mjs
@@ -22,7 +22,7 @@ export default defineConfig({
authcallback: resolve('authcallback.html'),
filemanager: resolve('filemanager.html'),
index: resolve('index.html'),
- login: resolve('login.html'),
+ oidc_login: resolve('oidc_login.html'),
oidc_error: resolve('oidc_error.html'),
oidc_interaction_confirm: resolve('oidc_interaction_confirm.html'),
oidc_interaction_abort: resolve('oidc_interaction_abort.html'),
diff --git a/src/oidcserver.js b/src/oidcserver.js
index abfa8d9dc..e75a81baf 100644
--- a/src/oidcserver.js
+++ b/src/oidcserver.js
@@ -40,8 +40,8 @@ const assert = require('assert'),
util = require('util');
// 1. Index.vue starts the OIDC flow by navigating to /openid/auth. Webadmin sets callback url to authcallback.html + implicit flow
// 2. oidcserver starts an interaction and redirects to login.html
// 3. login.html is rendered by renderInteractionPage() with the form submit url /interaction/:uid/login
// 4. When form is submitted, it invokes interactionLogin(). This validates user creds
// 5. We enter the scopes confirmation flow which is oidc_interaction_confirm.html rendered by renderInteractionPage()
// 6. We have no concept of confirmation. The page auto-submits the form immediately without user interaction
@@ -315,7 +315,7 @@ async function renderInteractionPage(req, res, next) {
options.ICON_URL = app.iconUrl;
}
- let html = fs.readFileSync(__dirname + '/../dashboard/dist/login.html', 'utf-8');
+ let html = fs.readFileSync(__dirname + '/../dashboard/dist/oidc_login.html', 'utf-8');
for (const key in options) {
html = html.replaceAll(`##${key}##`, options[key]);
}
@@ -40,8 +40,8 @@ const assert = require('assert'),
util = require('util');
// 1. Index.vue starts the OIDC flow by navigating to /openid/auth. Webadmin sets callback url to authcallback.html + implicit flow
-// 2. oidcserver starts an interaction and redirects to login.html
-// 3. login.html is rendered by renderInteractionPage() with the form submit url /interaction/:uid/login
+// 2. oidcserver starts an interaction and redirects to oidc_login.html
+// 3. oidc_login.html is rendered by renderInteractionPage() with the form submit url /interaction/:uid/login
// 4. When form is submitted, it invokes interactionLogin(). This validates user creds
// 5. We enter the scopes confirmation flow which is oidc_interaction_confirm.html rendered by renderInteractionPage()